from pathlib import Path

from pytest import fixture

import sfst_transduce

tests_dir = (Path(__file__) / "..").resolve()


@fixture
def transducer():
    return sfst_transduce.Transducer((tests_dir / "easy.a").as_posix())


@fixture
def compact_transducer():
    return sfst_transduce.CompactTransducer((tests_dir / "easy.ca").as_posix())



def assert_single_result(expected, results):
    assert len(results) == 1
    for result in results:
        assert result == expected


def test_transducer(transducer):
    assert_single_result("easy<ADJ><pos>", transducer.analyse("easy"))
    assert_single_result("easier", transducer.generate("easy<ADJ><comp>"))


def test_compact_transducer(compact_transducer):
    assert_single_result("easy<ADJ><pos>", compact_transducer.analyse("easy"))



# -*- coding: utf-8 -*-
from pybind11.setup_helpers import Pybind11Extension, build_ext
from setuptools import setup

setup(
    cmdclass={"build_ext": build_ext},
    ext_modules=[
        Pybind11Extension(
            "sfst_transduce",
            [
                "src/basic.cpp",
                "src/compact.cpp",
                "src/utf8.cpp",
                "src/alphabet.cpp",
                "src/fst.cpp",
                "src/operators.cpp",
                "src/determinise.cpp",
                "src/hopcroft.cpp",
                "python/sfst_transduce.cpp",
            ],
            define_macros=[("SFST_VERSION", open("VERSION").read().strip())],
        )
    ],
    zip_safe=False,
)
